@@ -16,17 +16,8 @@ getTikzDeviceVersion <- function() {
   as.character(packageVersion('tikzDevice'))
 }
 
-tikz_writeRaster <-
-function(
-  fileName, rasterCount, rasterData, nrows, ncols,
-  finalDims, interpolate
-){
-
-  raster_file <- basename(tools::file_path_sans_ext(fileName))
-  raster_file <- file.path(dirname(fileName),
-    paste(raster_file, '_ras', rasterCount, '.png', sep = '')
-  )
-
+tikz_writeRaster <- function(fileName, rasterCount, rasterData,
+                             nrows, ncols, finalDims, interpolate) {
   # Convert the 4 vectors of RGBA data contained in rasterData to a raster
   # image.
   rasterData[['maxColorValue']] = 255
@@ -34,6 +25,28 @@ function(
   rasterData = as.raster(
     matrix( rasterData, nrow = nrows, ncol = ncols, byrow = TRUE ) )
 
+  raster_file <- paste0(
+      tools::file_path_sans_ext(fileName),
+      '_ras', rasterCount, '.png')
+
+  res = getOption('tikzRasterResolution', NA)
+  if (is.na(res)) {
+      interpolate = FALSE
+      width = ncols
+      height = nrows
+      units = 'px'
+      dpi = 1
+  } else {
+      width = finalDims$width
+      height = finalDims$height
+      units = 'in'
+      dpi = res
+  }
+
+  png_type = 'Xlib'
+  if (Sys.info()['sysname'] == 'Windows')
+      png_type = getOption("bitmapType")
+
   # Write the image to a PNG file.
 
   # On OS X there is a problem with png() not respecting antialiasing options.
@@ -41,38 +54,26 @@ function(
   # being compiled into OS X binaries.  Technically, cannot count on Aqua/Quartz
   # either but you would have to be a special kind of special to leave it out.
   # Using type='Xlib' also causes a segfault for me on OS X 10.6.4
-  if ( Sys.info()['sysname'] == 'Darwin' && capabilities('aqua') ){
-
-    grDevices::quartz( file = raster_file, type = 'png',
-      width = finalDims$width, height = finalDims$height, antialias = FALSE,
-      dpi = getOption('tikzRasterResolution') )
-
-  } else if (Sys.info()['sysname'] == 'Windows') {
-
-    png( filename = raster_file, width = finalDims$width, height = finalDims$height,
-      units = 'in', res = getOption('tikzRasterResolution') )
-
+  if ( Sys.info()['sysname'] == 'Darwin' && capabilities('aqua') ) {
+      grDevices::quartz(
+          file = raster_file, type = 'png',
+          width = width, height = height,
+          antialias = FALSE, dpi = dpi )
   } else {
-
-    # Linux/UNIX and OS X without Aqua.
-    png( filename = raster_file, width = finalDims$width, height = finalDims$height,
-      type = 'Xlib', units = 'in', antialias = 'none',
-      res = getOption('tikzRasterResolution') )
-
+      png(filename = raster_file,
+          width = width, height = height,
+          units = units, res = dpi,
+          type = png_type, antialias = 'none' )
   }
 
-  par( mar = c(0,0,0,0) )
+  par(mar=c(0,0,0,0))
   plot.new()
-
   plotArea = par('usr')
-
   rasterImage(rasterData, plotArea[1], plotArea[3],
-    plotArea[2], plotArea[4], interpolate = interpolate )
-
+    plotArea[2], plotArea[4], interpolate = interpolate)
   dev.off()
 
   return(
     basename(tools::file_path_sans_ext(raster_file))
   )
-
 }
